@@ -15,13 +15,12 @@ use openpgp::types::{Curve, SymmetricAlgorithm};
 use openpgp::Cert;
 use sequoia_openpgp as openpgp;
 
-use openpgp_card::errors::OpenpgpCardError;
-use openpgp_card::DecryptMe;
+use openpgp_card::crypto_data::Cryptogram;
+use openpgp_card::{CardApp, Error};
 
 use crate::PublicKey;
-use openpgp_card::card_app::CardApp;
 
-pub(crate) struct CardDecryptor<'a> {
+pub struct CardDecryptor<'a> {
     /// The OpenPGP card (authenticated to allow decryption operations)
     ca: &'a mut CardApp,
 
@@ -38,10 +37,10 @@ impl<'a> CardDecryptor<'a> {
         ca: &'a mut CardApp,
         cert: &Cert,
         policy: &dyn Policy,
-    ) -> Result<CardDecryptor<'a>, OpenpgpCardError> {
+    ) -> Result<CardDecryptor<'a>, Error> {
         // Get the fingerprint for the decryption key from the card.
-        let ard = ca.get_app_data()?;
-        let fps = CardApp::get_fingerprints(&ard)?;
+        let ard = ca.get_application_related_data()?;
+        let fps = ard.get_fingerprints()?;
         let fp = fps.decryption();
 
         if let Some(fp) = fp {
@@ -63,12 +62,12 @@ impl<'a> CardDecryptor<'a> {
                 let public = keys[0].clone();
                 Ok(Self { ca, public })
             } else {
-                Err(OpenpgpCardError::InternalError(anyhow!(
+                Err(Error::InternalError(anyhow!(
                     "Failed to find a matching (sub)key in cert"
                 )))
             }
         } else {
-            Err(OpenpgpCardError::InternalError(anyhow!(
+            Err(Error::InternalError(anyhow!(
                 "Failed to get the decryption key's Fingerprint from the card"
             )))
         }
@@ -93,8 +92,8 @@ impl<'a> crypto::Decryptor for CardDecryptor<'a> {
     ) -> openpgp::Result<crypto::SessionKey> {
         match (ciphertext, self.public.mpis()) {
             (mpi::Ciphertext::RSA { c: ct }, mpi::PublicKey::RSA { .. }) => {
-                let dm = DecryptMe::RSA(ct.value());
-                let dec = self.ca.decrypt(dm)?;
+                let dm = Cryptogram::RSA(ct.value());
+                let dec = self.ca.decipher(dm)?;
 
                 let sk = openpgp::crypto::SessionKey::from(&dec[..]);
                 Ok(sk)
@@ -105,19 +104,24 @@ impl<'a> crypto::Decryptor for CardDecryptor<'a> {
             ) => {
                 let dm = if curve == &Curve::Cv25519 {
                     // Ephemeral key without header byte 0x40
-                    DecryptMe::ECDH(&e.value()[1..])
+                    Cryptogram::ECDH(&e.value()[1..])
                 } else {
                     // NIST curves: ephemeral key with header byte
-                    DecryptMe::ECDH(e.value())
+                    Cryptogram::ECDH(e.value())
                 };
 
                 // Decryption operation on the card
-                let mut dec = self.ca.decrypt(dm)?;
+                let mut dec = self.ca.decipher(dm)?;
 
-                // Specifically handle return value from Gnuk
+                // Specifically handle return value format like Gnuk's
                 // (Gnuk returns a leading '0x04' byte and
                 // an additional 32 trailing bytes)
                 if curve == &Curve::NistP256 && dec.len() == 65 {
+                    assert_eq!(
+                        dec[0], 0x04,
+                        "unexpected shape of decrypted data"
+                    );
+
                     // see Gnuk src/call-ec.c:82
                     dec = dec[1..33].to_vec();
                 }
